@@ -5,7 +5,7 @@ use Encode qw(decode);
 use base 'Exporter';
 our @EXPORT = qw(convert_to_ascii);
 our @EXPORT_OK = qw(convert_to_ascii);
-our $VERSION = '0.28';
+our $VERSION = '0.30';
 my %char_map;
 
 =encoding utf8
@@ -573,7 +573,7 @@ __DATA__
 0267 68
 0268 69
 0269 69
-026A 69
+026A 49
 026B 6C
 026C 6C
 026D 6C
@@ -2627,19 +2627,28 @@ A7F4 51
 A7F8 48
 A7F9 6F+65
 A7FE 49
+AB30 61
 AB31 61+65
+AB32 65
+AB33 65
 AB34 65
+AB35 66
+AB36 67
 AB37 6C
 AB38 6C
 AB39 6C
 AB3A 6D
 AB3B 6E
 AB3E 6F
+AB46 52
 AB47 72
 AB49 72
 AB4E 75
 AB4F 75
 AB52 75
+AB53 58
+AB54 58
+AB55 58
 AB56 78
 AB57 78
 AB58 78
@@ -2648,7 +2657,50 @@ AB5A 79
 AB5D 6C
 AB5E 6C
 AB5F 75
+AB64 61
 AB69 6D
+AB70 44
+AB71 52
+AB72 54
+AB74 4F
+AB75 69
+AB76 73
+AB79 79
+AB7A 41
+AB7B 4A
+AB7C 45
+AB7E 3F
+AB7F 41
+AB83 57
+AB85 70
+AB86 47
+AB87 4D
+AB8B 48
+AB8D 79
+AB90 47
+AB92 68
+AB93 7A
+AB96 49
+AB9B 45
+AB9E 34
+AB9F 62
+ABA2 52
+ABA4 57
+ABA5 67
+ABA9 76
+ABAA 73
+ABAE 4C
+ABAF 43
+ABB2 50
+ABB3 43
+ABB4 76
+ABB5 68
+ABB6 4B
+ABB7 64
+ABB8 43
+ABB9 47
+ABBE 36
+ABBF 77
 FB00 66+66
 FB01 66+69
 FB02 66+6C
@@ -2856,6 +2908,27 @@ FFEE 6F
 10346 46
 10347 58
 10348 4F
+1040E 57
+10415 43
+10419 50
+1041A 42
+1041B 4C
+1041E 36
+1041F 44
+10420 53
+10429 45
+1042C 4F
+10432 72
+10436 77
+1043D 63
+10441 70
+10442 42
+10443 4C
+10444 59
+10445 38
+10446 36
+10447 44
+10448 73
 10496 53
 104B2 41
 10781 3A
